@@ -6,19 +6,19 @@ Copyright 2004 Eric L. Wilhelm
 GPL / Artistic License
 See Polygon.pm for details
 
-Version 0.03 (pre-release copy)
+Version 0.04
 
 */
 
 #include "gpc.h"
 #include "gpc.c"
 
-/*#define DEBUG_PRINT;*/
+/*#define DEBUG_PRINT*/
 
 #ifdef DEBUG_PRINT
-    #define dbg_p(format, args...) printf(format, ## args);
+#define dbg_p(x) printf x
 #else
-    #define dbg_p(format, ...) ;
+#define dbg_p(x)
 #endif
 
 SV* new (char* class);
@@ -45,27 +45,27 @@ SV* new (char* class) {
 
 void DESTROY(SV* obj) {
 	gpc_polygon* p = (gpc_polygon*) SvIV(SvRV(obj));
-	dbg_p("running destroy for %d contours\n", p->num_contours);
+	dbg_p(("running destroy for %d contours\n", p->num_contours));
 	if(p->num_contours > 0) {
-		dbg_p("free contents now\n");
+		dbg_p(("free contents now\n"));
 		gpc_free_polygon2(p);
 	}
-	dbg_p("that's done now\n");
+	dbg_p(("that's done now\n"));
 	free(p);
-	dbg_p("p free... DESTROY complete\n");
+	dbg_p(("p free... DESTROY complete\n"));
 }
 
 int from_file(SV* obj, char* filename, int want_hole) {
 	gpc_polygon* p = (gpc_polygon*) SvIV(SvRV(obj));
 	FILE* sfp;
-	dbg_p("from %s file\n", filename);
+	dbg_p(("from %s file\n", filename));
 	sfp = fopen(filename, "r");
 	if(! sfp) {
-		dbg_p("file open failed\n");
+		dbg_p(("file open failed\n"));
 		return(0);
 	}
 	gpc_read_polygon(sfp, want_hole, p);
-	dbg_p("read %d contours\n", p->num_contours);
+	dbg_p(("read %d contours\n", p->num_contours));
 	return(p->num_contours);
 }
 
@@ -93,15 +93,15 @@ SV* clip_to(SV* obj, SV* clp, char* action) {
 	}
 	c = (gpc_polygon*) SvIV(SvRV(clp));
 	if(! strcmp(action, "INTERSECT")) {
-		dbg_p("performing INTERSECT\n");
+		dbg_p(("performing INTERSECT\n"));
 		op = GPC_INT;
 	}
 	if(! strcmp(action, "DIFFERENCE")) {
-		dbg_p("performing DIFFERENCE\n");
+		dbg_p(("performing DIFFERENCE\n"));
 		op = GPC_DIFF;
 	}
 	if(! strcmp(action, "UNION")) {
-		dbg_p("performing UNION\n");
+		dbg_p(("performing UNION\n"));
 		op = GPC_UNION;
 	}
 	/* FIXME: need some way to integrate this:
@@ -115,28 +115,28 @@ SV* clip_to(SV* obj, SV* clp, char* action) {
 
 void add_polygon(SV* obj, SV* pg, int hole) {
 	gpc_polygon* p = (gpc_polygon*) SvIV(SvRV(obj));
-	dbg_p("got my vl\n");
+	dbg_p(("got my vl\n"));
 	if(p->num_contours > 0) {
 		gpc_vertex_list* c;
 		MALLOC(c, sizeof(gpc_vertex_list), 
 			"addable contour creation\n");
 		pts_to_vertex_list(pg, c);
-		dbg_p("adding to existing\n");
+		dbg_p(("adding to existing\n"));
 		gpc_add_contour(p, c, hole);
 	}
 	else {
-		dbg_p("adding as new\n");
+		dbg_p(("adding as new\n"));
 		MALLOC(p->hole, sizeof(int), "hole flag array\n");
-		dbg_p("setting hole\n");
+		dbg_p(("setting hole\n"));
 		p->hole[0] = hole;
-		dbg_p("making contour\n");
+		dbg_p(("making contour\n"));
 		MALLOC(p->contour, sizeof(gpc_vertex_list), 
 			"contour creation\n");
 		pts_to_vertex_list(pg, &(p->contour[0]) );
-		dbg_p("got %d vertices\n", p->contour[0].num_vertices);
+		dbg_p(("got %d vertices\n", p->contour[0].num_vertices));
 		p->num_contours = 1;
 	}
-	dbg_p("added\n");
+	dbg_p(("added\n"));
 }
 
 void get_polygons(SV* obj) {
@@ -145,7 +145,7 @@ void get_polygons(SV* obj) {
 	gpc_polygon* p = (gpc_polygon*) SvIV(SvRV(obj));
 	Inline_Stack_Reset;
 	if(p->num_contours < 1) {
-		dbg_p("no contours\n");
+		dbg_p(("no contours\n"));
 		Inline_Stack_Done;
 		return;
 	}
@@ -168,10 +168,10 @@ void pts_to_vertex_list(SV* pg, gpc_vertex_list* vl) {
 		croak("polygon must be reference\n");
 	pts = (AV*)SvRV(pg);
 	num = av_len(pts) + 1;
-	dbg_p("going to allocate for %d pts\n", num);
+	dbg_p(("going to allocate for %d pts\n", num));
 	MALLOC(vl->vertex, num * sizeof(gpc_vertex), "vertex creation");
 	vl->num_vertices = num;
-	dbg_p("MALLOC okay (%d vertices)\n", vl->num_vertices);
+	dbg_p(("MALLOC okay (%d vertices)\n", vl->num_vertices));
 	for(p = 0; p < num; p++) {
 		psv = av_fetch(pts, p, 0);
 		val = *psv;
@@ -184,27 +184,27 @@ void pts_to_vertex_list(SV* pg, gpc_vertex_list* vl) {
 		psv = av_fetch(pt, 1, 0);
 		val = *psv;
 		vl->vertex[p].y = SvNV(val);
-		dbg_p("added %0.2f, %0.2f\n", 
+		dbg_p(("added %0.2f, %0.2f\n", 
 			vl->vertex[p].x, vl->vertex[p].y
-			);
+			));
 	}
-	dbg_p("returning\n");
+	dbg_p(("returning\n"));
 }
 
 AV* vertex_list_to_pts(gpc_vertex_list* vl) {
 	AV* pts;
 	AV* pt;
 	int p;
-	dbg_p("%d vertices\n", vl->num_vertices);
+	dbg_p(("%d vertices\n", vl->num_vertices));
 	pts = newAV();
 	for(p = 0; p < vl->num_vertices; p++) {
 		pt = newAV();
 		av_push(pts, newRV_noinc((SV*) pt));
 		av_push(pt, newSVnv(vl->vertex[p].x));
 		av_push(pt, newSVnv(vl->vertex[p].y));
-		dbg_p("point %d: %0.2f, %0.2f\n", 
+		dbg_p(("point %d: %0.2f, %0.2f\n", 
 			p, vl->vertex[p].x, vl->vertex[p].y
-			);
+			));
 	}
 	return(pts);
 }
@@ -213,12 +213,12 @@ AV* vertex_list_to_pts(gpc_vertex_list* vl) {
 void gpc_free_polygon2(gpc_polygon *p) {
 	int c;
 	for (c= 0; c < p->num_contours; c++) {
-  	dbg_p("free contour %d\n", c);
+  	dbg_p(("free contour %d\n", c));
     FREE(p->contour[c].vertex);
 	}
-	dbg_p("free hole\n");
+	dbg_p(("free hole\n"));
 	FREE(p->hole);
-	dbg_p("free contour\n");
+	dbg_p(("free contour\n"));
 	FREE(p->contour);
 	p->num_contours= 0;
 }
